Use PyGTK in a virtualenv on Linux, Windows or OSX.
===================================================

Usage
-----

```pip install vext.pygtk``` or add  ```vext.pygtk``` to your requirements.txt


Dependencies
------------

pygtk installed in the system python

Debian / Ubuntu

``` $ sudo apt-get install python-pygtk```

SuSE

``` $ zypper install python-gtk``

Fedora, Redhat, Centos

``` $ yum install pygtk2```

Windows

The pygtk all-in-one installer is work pretty well, there are other options - mixing them can cause issues.

Install it manually or if you have chocolatey you can just run ```choco install pygtk-all-in-one``` in a console window as Administrator.
